@@ -55,7 +55,7 @@
 #define MOD_GM_COMMON_H
 
 /* constants */
-#define GM_VERSION                 "4.0.3"
+#define GM_VERSION                 "4.0.3.20220729"
 #define GM_ENABLED                      1
 #define GM_DISABLED                     0
 #define GM_BUFFERSIZE               65536
@@ -90,7 +90,6 @@
 #define GM_LOG_MODE_CORE                3
 #define GM_LOG_MODE_SYSLOG              4
 #define GM_LOG_MODE_TOOLS               5
-#define GM_LOG_MODE_CHECKS              6
 
 /* job priorities */
 #define GM_JOB_PRIO_LOW                 1
@@ -200,7 +199,6 @@ typedef struct mod_gm_opt_struct {
     int            logmode;                                 /**< logmode: auto, syslog, file or core */
     char         * logfile;                                 /**< path for the logfile */
     FILE         * logfile_fp;                              /**< filedescriptor for the logfile */
-    int            log_stats_interval;                      /**< interval in seconds to log gearman submission statistics  */
     int            use_uniq_jobs;                           /**< flag whether normal jobs will be sent with/without uniq set */
 /* neb module */
     char         * result_queue;                            /**< name of the result queue used by the neb module */
@@ -284,6 +282,7 @@ typedef struct gm_job_struct {
     int            early_timeout;       /**< did the check run into a timeout */
     int            check_options;       /**< check_options given from the core */
     int            scheduled_check;     /**< normal scheduled check? */
+    int            reschedule_check;    /**< rescheduled check? */
     int            exited_ok;           /**< did the plugin exit normally? */
     int            timeout;             /**< timeout for this job */
     double         latency;             /**< latency for from this job */
